@@ -311,7 +311,7 @@ def main(prog_or_class, singleton = SINGLETON_NOT_SINGLETON, multiproc_logging =
         logger.critical(errinfo)
         
         exit_code, exit_message = prog.EXITCODE_MAIN_FAILURE
-        exit_message = str(e) or exit_message
+        exit_message = '%s: %s' % (e.__class__.__name__, e.message or 'No message')
         
     try:
         logger.info('Finalizing program.')
@@ -323,7 +323,7 @@ def main(prog_or_class, singleton = SINGLETON_NOT_SINGLETON, multiproc_logging =
         logger.critical(errinfo)
         
         exit_code, exit_message = prog.EXITCODE_FINALIZATION_FAILURE
-        exit_message = str(e) or exit_message
+        exit_message = '%s: %s' % (e.__class__.__name__, e.message or 'No message')
         
     if exit_code:
         try:
